Config Class
Config.RdRepresents the complete configuration for the pipeline.
Usage
Config(
job_id = class_missing,
task_id = class_missing,
min_reference_date = class_missing,
max_reference_date = class_missing,
report_date = class_missing,
production_date = class_missing,
disease = class_missing,
low_case_count_thresholds = class_missing,
geo_value = class_missing,
geo_type = class_missing,
seed = class_missing,
horizon = class_missing,
model = class_missing,
config_version = class_missing,
quantile_width = class_missing,
data = class_missing,
priors = class_missing,
parameters = class_missing,
sampler_opts = class_missing,
exclusions = class_missing,
output_container = class_missing,
facility_active_proportion = class_missing
)Arguments
- job_id
A string specifying the job.
- task_id
A string specifying the task.
- min_reference_date
A string representing the minimum reference date. Formatted as "YYYY-MM-DD".
- max_reference_date
A string representing the maximum reference date. Formatted as "YYYY-MM-DD".
- report_date
A string representing the report date. Formatted as "YYYY-MM-DD".
- production_date
A string representing the production date. Formatted as "YYYY-MM-DD".
- disease
A string specifying the disease being modeled. One of
"COVID-19"or"Influenza"or"RSV".- low_case_count_thresholds
A named list of thresholds to use for determining n_low_case_count in diagnostic file Example: list(
COVID-19= 10,Influenza`` = 10,RSV` = 5)- geo_value
An uppercase, two-character string specifying the geographic value, usually a state or
"US"for national data.- geo_type
A string specifying the geographic type, usually "state".
- seed
An integer for setting the random seed.
- horizon
An integer specifying the forecasting horizon.
- model
A string specifying the model to be used.
- config_version
A numeric value specifying the configuration version.
- quantile_width
A vector of numeric values representing the desired quantiles. Passed to
tidybayes::median_qi().- data
An instance of
Dataclass containing data configurations.- priors
A list of lists. The first level should contain the key
rtwith elementsmeanandsdand the keygpwith elementalpha_sd.- parameters
An instance of
Parametersclass containing parameter configurations.- sampler_opts
A list. The Stan sampler options to be passed through EpiNow2. It has required keys:
cores,chains,iter_warmup,iter_sampling,max_treedepth, andadapt_delta.- exclusions
An instance of
Exclusionsclass containing exclusion criteria.- output_container
An optional string specifying the output blob storage container.
- facility_active_proportion
A numeric value between 0 and 1 specifying the proportion of days during the modeling period that facilities must have reported at least one informative discharge diagnosis (DDI) to be included in the analysis. Default is 0.94 (require active reporting for >=53 of 56 days in the training period). Lower values allow inclusion of facilities with fewer active days.
See also
Other config:
Data(),
Interval,
Parameters(),
read_json_into_config()